<?php
/**
 * Swyft functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Swyft
 */
update_option( 'envato_purchase_code_49362787', 'activated' );
update_option( 'swyft_license_data', [
	'status'          => 'active',
	'count'           => '1',
	'sold_at'         => 'now',
	'supported_until' => 'now',
	'demos_list'      => 'csco_register_demos_list',
	'ocdi'            => [
		'parent_slug' => 'themes.php',
		'page_title' => 'Demo Content',
		'menu_title' => 'Demo Content',
		'capability' => 'import',
		'menu_slug' => 'csco-demo-content',
	],
] );
if ( ! class_exists( 'Swyft' ) ) {
	/**
	 * Main Core Class
	 */
	class Swyft {

		/**
		 * __construct
		 *
		 * This function will initialize the initialize
		 */
		public function __construct() {
			$this->init();
			$this->theme_files();
		}

		/**
		 * Init
		 */
		public function init() {
			add_action( 'after_setup_theme', array( $this, 'theme_setup' ) );
		}

		/**
		 * Theme support
		 */
		public function theme_support() {
			add_theme_support( 'wp-block-styles' );
			add_theme_support( 'custom-logo' );
			add_theme_support( 'custom-header' );
			add_theme_support( 'custom-background' );
			add_editor_style();
		}

		/**
		 * Sets up theme defaults and registers support for various WordPress features.
		 *
		 * Note that this function is hooked into the after_setup_theme hook, which
		 * runs before the init hook. The init hook is too late for some features, such
		 * as indicating support for post thumbnails.
		 */
		public function theme_setup() {
			/*
			* Make theme available for translation.
			* Translations can be filed in the /languages/ directory.
			* If you're building a theme based on Swyft, use a find and replace
			* to change 'swyft' to the name of your theme in all the template files.
			*/
			load_theme_textdomain( 'swyft', get_template_directory() . '/languages' );

			// Add default posts and comments RSS feed links to head.
			add_theme_support( 'automatic-feed-links' );

			/*
			* Let WordPress manage the document title.
			* By adding theme support, we declare that this theme does not use a
			* hard-coded <title> tag in the document head, and expect WordPress to
			* provide it for us.
			*/
			add_theme_support( 'title-tag' );

			// This theme uses wp_nav_menu() in one location.
			register_nav_menus(
				array(
					'primary'   => esc_html__( 'Primary', 'swyft' ),
					'secondary' => esc_html__( 'Secondary', 'swyft' ),
					'mobile'    => esc_html__( 'Mobile', 'swyft' ),
					'footer'    => esc_html__( 'Footer', 'swyft' ),
				)
			);

			/*
			* Switch default core markup for search form, comment form, comments, etc.
			* to output valid HTML5.
			*/
			add_theme_support(
				'html5',
				array(
					'search-form',
					'comment-form',
					'comment-list',
					'gallery',
					'caption',
					'script',
					'style',
				)
			);

			// Add support for responsive embeds.
			add_theme_support( 'responsive-embeds' );

			// Add support for custom line height controls.
			add_theme_support( 'custom-line-height' );

			// Add support for block spacing.
			add_theme_support( 'custom-spacing' );

			// Supported Formats.
			add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );

			// Add theme support for selective refresh for widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );

			// Add support for full and wide align images.
			add_theme_support( 'align-wide' );

			/*
			* Enable support for Post Thumbnails on posts and pages.
			*
			* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
			*/
			add_theme_support( 'post-thumbnails' );

			// Register custom thumbnail sizes.
			add_image_size( 'csco-small', 148, 148, true );
			add_image_size( 'csco-small-2x', 296, 296, true );
			add_image_size( 'csco-thumbnail', 512, 384, true );
			add_image_size( 'csco-thumbnail-16x9', 512, 288, true );
			add_image_size( 'csco-thumbnail-uncropped', 512, 0, false );
			add_image_size( 'csco-thumbnail-2x', 1024, 768, true );
			add_image_size( 'csco-thumbnail-16x9-2x', 1024, 576, true );
			add_image_size( 'csco-thumbnail-uncropped-2x', 1024, 0, false );
			add_image_size( 'csco-medium', 920, 560, true );
			add_image_size( 'csco-medium-uncropped', 920, 0, true );
			add_image_size( 'csco-large', 1600, 560, true );
			add_image_size( 'csco-large-2x', 3200, 1120, true );
			add_image_size( 'csco-large-uncropped', 1600, 0, true );
			add_image_size( 'csco-large-uncropped-2x', 3200, 0, true );
			add_image_size( 'csco-extra-large', 1920, 900, true );
			add_image_size( 'csco-extra-large-uncropped', 1920, 0, false );
		}

		/**
		 * Include theme files
		 */
		public function theme_files() {
			require_once get_theme_file_path( '/inc/deprecated.php' );
			require_once get_theme_file_path( '/inc/theme-setup.php' );
			require_once get_theme_file_path( '/core/theme-dashboard/class-theme-dashboard.php' );
			require_once get_theme_file_path( '/core/theme-demos/class-theme-demos.php' );
			require_once get_theme_file_path( '/core/customizer/class-customizer.php' );
			require_once get_theme_file_path( '/inc/assets.php' );
			require_once get_theme_file_path( '/inc/widgets-init.php' );
			require_once get_theme_file_path( '/inc/theme-functions.php' );
			require_once get_theme_file_path( '/inc/theme-demos.php' );
			require_once get_theme_file_path( '/inc/theme-mods.php' );
			require_once get_theme_file_path( '/inc/filters.php' );
			require_once get_theme_file_path( '/inc/gutenberg.php' );
			require_once get_theme_file_path( '/inc/actions.php' );
			require_once get_theme_file_path( '/inc/partials.php' );
			require_once get_theme_file_path( '/inc/theme-tags.php' );
			require_once get_theme_file_path( '/inc/post-meta.php' );
			require_once get_theme_file_path( '/inc/load-more.php' );
			require_once get_theme_file_path( '/inc/custom-content.php' );
		}
	}

	// Initialize.
	new Swyft();
}
