<?php
/**
 * Header Settings
 *
 * @package Swyft
 */

CSCO_Customizer::add_section(
	'header',
	array(
		'title' => esc_html__( 'Header Settings', 'swyft' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'header_collapsible_common',
		'section'     => 'header',
		'label'       => esc_html__( 'Common', 'swyft' ),
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'header_layout',
		'label'    => esc_html__( 'Layout', 'swyft' ),
		'section'  => 'header',
		'default'  => 'cs-header-one',
		/**
		 * The csco_header hook.
		 *
		 * @since 1.0.0
		 */
		'choices'  => apply_filters(
			'csco_header_layouts',
			array(
				'cs-header-one'   => esc_html__( 'Header 1', 'swyft' ),
				'cs-header-two'   => esc_html__( 'Header 2', 'swyft' ),
				'cs-header-three' => esc_html__( 'Header 3', 'swyft' ),
			)
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'header_initial_height',
		'label'    => esc_html__( 'Header Initial Height', 'swyft' ),
		'section'  => 'header',
		'default'  => '80px',
		'output'   => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-initial-height',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'header_height',
		'label'    => esc_html__( 'Header Height', 'swyft' ),
		'section'  => 'header',
		'default'  => '80px',
		'output'   => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-height',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'header_topbar_height',
		'label'           => esc_html__( 'Header Topbar Height', 'swyft' ),
		'section'         => 'header',
		'default'         => '162px',
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => '==',
				'value'    => 'cs-header-three',
			),
		),
		'output'          => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-topbar-height',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'header_border_width',
		'label'    => esc_html__( 'Header Border Width', 'swyft' ),
		'section'  => 'header',
		'default'  => '1px',
		'output'   => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-border-width',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'checkbox',
		'settings'    => 'navbar_sticky',
		'label'       => esc_html__( 'Make navigation bar sticky', 'swyft' ),
		'description' => esc_html__( 'Enabling this option will make navigation bar visible when scrolling.', 'swyft' ),
		'section'     => 'header',
		'default'     => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'navbar_smart_sticky',
		'label'           => esc_html__( 'Enable the smart sticky feature', 'swyft' ),
		'description'     => esc_html__( 'Enabling this option will reveal navigation bar when scrolling up and hide it when scrolling down.', 'swyft' ),
		'section'         => 'header',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'navbar_sticky',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_offcanvas',
		'label'    => esc_html__( 'Display offcanvas toggle button', 'swyft' ),
		'section'  => 'header',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_navigation_menu',
		'label'    => esc_html__( 'Display navigation menu', 'swyft' ),
		'section'  => 'header',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_navigation_secondary_menu',
		'label'    => esc_html__( 'Display navigation secondary menu', 'swyft' ),
		'section'  => 'header',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_search',
		'section'  => 'header',
		'label'    => esc_html__( 'Search', 'swyft' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_search_button',
		'label'    => esc_html__( 'Display search button', 'swyft' ),
		'section'  => 'header',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_custom_button',
		'section'  => 'header',
		'label'    => esc_html__( 'Custom Button', 'swyft' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_custom_button',
		'label'    => esc_html__( 'Display custom button', 'swyft' ),
		'section'  => 'header',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_custom_button_label',
		'label'           => esc_html__( 'Button Label', 'swyft' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_custom_button',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_custom_button_link',
		'label'           => esc_html__( 'Button Link', 'swyft' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_custom_button',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
