<?php
/**
 * Homepage Settings
 *
 * @package Swyft
 */

/**
 * Removes default WordPress Static Front Page section
 * and re-adds it in our own panel with the same parameters.
 *
 * @param object $wp_customize Instance of the WP_Customize_Manager class.
 */
function csco_reorder_customizer_settings( $wp_customize ) {

	// Get current front page section parameters.
	$static_front_page = $wp_customize->get_section( 'static_front_page' );

	// Remove existing section, so that we can later re-add it to our panel.
	$wp_customize->remove_section( 'static_front_page' );

	// Re-add static front page section with a new name, but same description.
	$wp_customize->add_section(
		'static_front_page',
		array(
			'title'           => esc_html__( 'Static Front Page', 'swyft' ),
			'description'     => $static_front_page->description,
			'panel'           => 'home_panel',
			'active_callback' => $static_front_page->active_callback,
		)
	);
}
add_action( 'customize_register', 'csco_reorder_customizer_settings' );

CSCO_Customizer::add_panel(
	'home_panel',
	array(
		'title' => esc_html__( 'Front Page Settings', 'swyft' ),
	)
);

CSCO_Customizer::add_section(
	'home_settings',
	array(
		'title' => esc_html__( 'Latest Posts Layout', 'swyft' ),
		'panel' => 'home_panel',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'home_collapsible_common',
		'section'     => 'home_settings',
		'label'       => esc_html__( 'Common', 'swyft' ),
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'home_sidebar',
		'label'    => esc_html__( 'Default Sidebar', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => 'right',
		'choices'  => array(
			'right'    => esc_html__( 'Right Sidebar', 'swyft' ),
			'left'     => esc_html__( 'Left Sidebar', 'swyft' ),
			'disabled' => esc_html__( 'No Sidebar', 'swyft' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'home_layout',
		'label'    => esc_html__( 'Layout', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => 'grid',
		'choices'  => array(
			'grid'     => esc_html__( 'Grid Layout', 'swyft' ),
			'list'     => esc_html__( 'List Layout', 'swyft' ),
			'timeline' => esc_html__( 'Timeline Layout', 'swyft' ),
			'full'     => esc_html__( 'Full Post Layout', 'swyft' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'home_excerpt',
		'label'           => esc_html__( 'Display excerpt', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => false,
		'active_callback' => array(
			array(
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'list',
				),
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'grid',
				),
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'timeline',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'home_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 'landscape',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'swyft' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'swyft' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'swyft' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'swyft' ),
			'landscape-21-9' => esc_html__( 'Landscape 21:9', 'swyft' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'swyft' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'swyft' ),
			'portrait-6-7'   => esc_html__( 'Portrait 6:7', 'swyft' ),
			'square'         => esc_html__( 'Square', 'swyft' ),
		),
		'active_callback' => array(
			array(
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'list',
				),
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'grid',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'home_image_size',
		'label'           => esc_html__( 'Image Size', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 'csco-thumbnail',
		'choices'         => csco_get_list_available_image_sizes(),
		'active_callback' => array(
			array(
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'list',
				),
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'grid',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'home_media_preview',
		'label'           => esc_html__( 'Post Preview Image Size', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 'uncropped',
		'choices'         => array(
			'cropped'   => esc_html__( 'Display Cropped Image', 'swyft' ),
			'uncropped' => esc_html__( 'Display Preview in Original Ratio', 'swyft' ),
		),
		'active_callback' => array(
			array(
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'full',
				),
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'timeline',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'home_summary',
		'label'           => esc_html__( 'Full Post Summary', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 'summary',
		'choices'         => array(
			'summary' => esc_html__( 'Use Excerpts', 'swyft' ),
			'content' => esc_html__( 'Use Read More Tag', 'swyft' ),
		),
		'active_callback' => array(
			array(
				array(
					'setting'  => 'home_layout',
					'operator' => '==',
					'value'    => 'full',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'home_pagination_type',
		'label'    => esc_html__( 'Pagination', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => 'load-more',
		'choices'  => array(
			'standard'  => esc_html__( 'Standard', 'swyft' ),
			'load-more' => esc_html__( 'Load More Button', 'swyft' ),
			'infinite'  => esc_html__( 'Infinite Load', 'swyft' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'home_collapsible_post_meta',
		'section'     => 'home_settings',
		'label'       => esc_html__( 'Post Meta', 'swyft' ),
		'input_attrs' => array(
			'collapsed' => false,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'multicheck',
		'settings' => 'home_post_meta',
		'label'    => esc_html__( 'Post Meta', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => array( 'category', 'date', 'author' ),
		/**
		 * Post meta choices.
		 *
		 * @since 1.0.0
		 */
		'choices'  => apply_filters( 'csco_post_meta_choices', array(
			'category' => esc_html__( 'Category', 'swyft' ),
			'date'     => esc_html__( 'Date', 'swyft' ),
			'author'   => esc_html__( 'Author', 'swyft' ),
			'comments' => esc_html__( 'Comments', 'swyft' ),
		) ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'collapsible',
		'settings'        => 'home_collapsible_number_of_columns',
		'section'         => 'home_settings',
		'label'           => esc_html__( 'Number of Columns', 'swyft' ),
		'input_attrs'     => array(
			'collapsed' => false,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_columns_desktop',
		'label'           => esc_html__( 'Desktop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 2,
		'input_attrs'     => array(
			'min'  => 1,
			'max'  => 3,
			'step' => 1,
		),
		'output'          => array(
			array(
				'element'  => '.cs-posts-area__home.cs-posts-area__grid',
				'property' => '--cs-posts-area-grid-columns',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_columns_laptop',
		'label'           => esc_html__( 'Laptop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 2,
		'input_attrs'     => array(
			'min'  => 1,
			'max'  => 4,
			'step' => 1,
		),
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-columns',
				'media_query' => '@media (max-width: 1199.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_columns_tablet',
		'label'           => esc_html__( 'Tablet', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 2,
		'input_attrs'     => array(
			'min'  => 1,
			'max'  => 4,
			'step' => 1,
		),
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-columns',
				'media_query' => '@media (max-width: 991.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_columns_mobile',
		'label'           => esc_html__( 'Mobile', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => 1,
		'input_attrs'     => array(
			'min'  => 1,
			'max'  => 4,
			'step' => 1,
		),
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-columns',
				'media_query' => '@media (max-width: 575.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'collapsible',
		'settings'        => 'home_collapsible_gap_between_rows',
		'section'         => 'home_settings',
		'label'           => esc_html__( 'Gap between Rows', 'swyft' ),
		'input_attrs'     => array(
			'collapsed' => false,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '!=',
				'value'    => 'timeline',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_rows_desktop',
		'label'           => esc_html__( 'Desktop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '64px',
		'output'          => array(
			array(
				'element'  => '.cs-posts-area__home',
				'property' => '--cs-posts-area-grid-row-gap',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '!=',
				'value'    => 'timeline',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_rows_laptop',
		'label'           => esc_html__( 'Laptop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '48px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-posts-area-grid-row-gap',
				'media_query' => '@media (max-width: 1199.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '!=',
				'value'    => 'timeline',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_rows_tablet',
		'label'           => esc_html__( 'Tablet', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '40px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-posts-area-grid-row-gap',
				'media_query' => '@media (max-width: 991.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '!=',
				'value'    => 'timeline',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_rows_mobile',
		'label'           => esc_html__( 'Mobile', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '40px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-posts-area-grid-row-gap',
				'media_query' => '@media (max-width: 575.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '!=',
				'value'    => 'timeline',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'collapsible',
		'settings'        => 'home_collapsible_gap_between_columns',
		'section'         => 'home_settings',
		'label'           => esc_html__( 'Gap between Columns', 'swyft' ),
		'input_attrs'     => array(
			'collapsed' => false,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_columns_desktop',
		'label'           => esc_html__( 'Desktop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '32px',
		'output'          => array(
			array(
				'element'  => '.cs-posts-area__home.cs-posts-area__grid',
				'property' => '--cs-posts-area-grid-column-gap',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_columns_laptop',
		'label'           => esc_html__( 'Laptop', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '24px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-column-gap',
				'media_query' => '@media (max-width: 1199.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_columns_tablet',
		'label'           => esc_html__( 'Tablet', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '24px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-column-gap',
				'media_query' => '@media (max-width: 991.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'home_gap_between_columns_mobile',
		'label'           => esc_html__( 'Mobile', 'swyft' ),
		'section'         => 'home_settings',
		'default'         => '24px',
		'output'          => array(
			array(
				'element'     => '.cs-posts-area__home.cs-posts-area__grid',
				'property'    => '--cs-posts-area-grid-column-gap',
				'media_query' => '@media (max-width: 575.98px)',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_layout',
				'operator' => '==',
				'value'    => 'grid',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'home_collapsible_title_size',
		'section'     => 'home_settings',
		'label'       => esc_html__( 'Title Font Size', 'swyft' ),
		'input_attrs' => array(
			'collapsed' => false,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'home_title_size_desktop',
		'label'    => esc_html__( 'Desktop', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => '1.5rem',
		'output'   => array(
			array(
				'element'  => '.cs-posts-area__home',
				'property' => '--cs-entry-title-font-size',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'home_title_size_laptop',
		'label'    => esc_html__( 'Laptop', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => '1.5rem',
		'output'   => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-entry-title-font-size',
				'media_query' => '@media (max-width: 1199.98px)',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'home_title_size_tablet',
		'label'    => esc_html__( 'Tablet', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => '1.5rem',
		'output'   => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-entry-title-font-size',
				'media_query' => '@media (max-width: 991.98px)',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'home_title_size_mobile',
		'label'    => esc_html__( 'Mobile', 'swyft' ),
		'section'  => 'home_settings',
		'default'  => '1.5rem',
		'output'   => array(
			array(
				'element'     => '.cs-posts-area__home',
				'property'    => '--cs-entry-title-font-size',
				'media_query' => '@media (max-width: 575.98px)',
			),
		),
	)
);

CSCO_Customizer::add_section(
	'home_hero_section', array(
		'title'    => esc_html__( 'Hero Section', 'swyft' ),
		'panel'    => 'home_panel',
		'priority' => 10,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'home_hero',
		'label'    => esc_html__( 'Display hero section', 'swyft' ),
		'section'  => 'home_hero_section',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'collapsible',
		'settings'        => 'home_hero_collapsible_common',
		'section'         => 'home_hero_section',
		'label'           => esc_html__( 'Common', 'swyft' ),
		'input_attrs'     => array(
			'collapsed' => true,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'home_hero_layout',
		'label'           => esc_html__( 'Layout', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => 'hero-type-1',
		'priority'        => 10,
		'choices'         => array(
			'hero-type-1' => esc_html__( 'Type 1', 'swyft' ),
			'hero-type-2' => esc_html__( 'Type 2', 'swyft' ),
			'hero-type-3' => esc_html__( 'Type 3', 'swyft' ),
			'hero-type-4' => esc_html__( 'Type 4', 'swyft' ),
			'hero-type-5' => esc_html__( 'Type 5', 'swyft' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'home_hero_slider_autoplay',
		'label'           => esc_html__( 'Slider Autoplay', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => 'yes',
		'priority'        => 10,
		'choices'         => array(
			'yes' => esc_html__( 'Enabled', 'swyft' ),
			'no'  => esc_html__( 'Disabled', 'swyft' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
			array(
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-1',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-4',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-5',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_hero_slider_delay',
		'label'           => esc_html__( 'Autoplay Delay (ms)', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => '5000',
		'input_attrs'     => array(
			'min'  => 3000,
			'max'  => 10000,
			'step' => 500,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'home_hero_slider_autoplay',
				'operator' => '==',
				'value'    => 'yes',
			),
			array(
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-1',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-4',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-5',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'home_hero_slider_parallax',
		'label'           => esc_html__( 'Slider Parallax Effect', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => 'yes',
		'priority'        => 10,
		'choices'         => array(
			'yes' => esc_html__( 'Enabled', 'swyft' ),
			'no'  => esc_html__( 'Disabled', 'swyft' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
			array(
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-1',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-4',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-5',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'multicheck',
		'settings'        => 'home_hero_meta',
		'label'           => esc_html__( 'Post Meta', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => array( 'category', 'author', 'date' ),
		'priority'        => 10,
		'choices'         => apply_filters( 'csco_post_meta_choices', array(
			'category' => esc_html__( 'Category', 'swyft' ),
			'author'   => esc_html__( 'Author', 'swyft' ),
			'date'     => esc_html__( 'Date', 'swyft' ),
			'comments' => esc_html__( 'Comments', 'swyft' ),
		) ),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'home_hero_filter_categories',
		'label'           => esc_html__( 'Filter by Categories', 'swyft' ),
		'description'     => esc_html__( 'Add comma-separated list of category slugs. For example: &laquo;travel, lifestyle, food&raquo;. Leave empty for all categories.', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => '',
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'home_hero_filter_tags',
		'label'           => esc_html__( 'Filter by Tags', 'swyft' ),
		'description'     => esc_html__( 'Add comma-separated list of tag slugs. For example: &laquo;worth-reading, top-5, playlists&raquo;. Leave empty for all tags.', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => '',
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'home_hero_filter_posts',
		'label'           => esc_html__( 'Filter by Posts', 'swyft' ),
		'description'     => esc_html__( 'Add comma-separated list of post IDs (max. 5). For example: 12, 34, 145. Leave empty for all posts.', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => '',
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'home_hero_max_count',
		'label'           => esc_html__( 'Maximum Posts', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => '5',
		'input_attrs'     => array(
			'min'  => 1,
			'max'  => 100,
			'step' => 1,
		),
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
			array(
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-1',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-4',
				),
				array(
					'setting'  => 'home_hero_layout',
					'operator' => '==',
					'value'    => 'hero-type-5',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'home_hero_exclude',
		'label'           => esc_html__( 'Exclude hero posts from the main archive', 'swyft' ),
		'section'         => 'home_hero_section',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'home_hero',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
