<?php
/**
 * Post Settings
 *
 * @package Swyft
 */

CSCO_Customizer::add_section(
	'post_settings',
	array(
		'title' => esc_html__( 'Post Settings', 'swyft' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'post_collapsible_common',
		'section'     => 'post_settings',
		'label'       => esc_html__( 'Common', 'swyft' ),
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'post_sidebar',
		'label'    => esc_html__( 'Default Sidebar', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => 'right',
		'choices'  => array(
			'right'    => esc_html__( 'Right Sidebar', 'swyft' ),
			'left'     => esc_html__( 'Left Sidebar', 'swyft' ),
			'disabled' => esc_html__( 'No Sidebar', 'swyft' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'post_header_type',
		'label'    => esc_html__( 'Default Page Header Type', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => 'standard',
		'choices'  => array(
			'standard'      => esc_html__( 'Standard', 'swyft' ),
			'large_overlay' => esc_html__( 'Large Overlay', 'swyft' ),
			'title'         => esc_html__( 'Page Title Only', 'swyft' ),
			'none'          => esc_html__( 'None', 'swyft' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'multicheck',
		'settings' => 'post_meta',
		'label'    => esc_html__( 'Post Meta', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => array( 'category', 'date', 'author' ),
		/**
		 * Post meta choices.
		 *
		 * @since 1.0.0
		 */
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category' => esc_html__( 'Category', 'swyft' ),
				'date'     => esc_html__( 'Date', 'swyft' ),
				'author'   => esc_html__( 'Author', 'swyft' ),
				'comments' => esc_html__( 'Comments', 'swyft' ),
			)
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_subtitle',
		'label'    => esc_html__( 'Display excerpt as post subtitle', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_tags',
		'label'    => esc_html__( 'Display tags', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_footer',
		'label'    => esc_html__( 'Display post footer', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_read_next',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Read Next Links', 'swyft' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_read_next',
		'label'    => esc_html__( 'Display read next links', 'swyft' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'post_read_next_posts',
		'label'           => esc_html__( 'Display posts', 'swyft' ),
		'description'     => esc_html__( 'The section will display posts from the current category, published after the current post\'s date, before it, or the newest posts. In case fewer than tree or four posts meet the requirements, the section will display other posts from the current category. In case there are fewer than three or four posts in the current category, the section will display posts from other categories.', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => 'after',
		'choices'         => apply_filters(
			'csco_header_layouts',
			array(
				'after'  => esc_html__( 'After current post date', 'swyft' ),
				'before' => esc_html__( 'Before current post date', 'swyft' ),
				'new'    => esc_html__( 'Newest posts', 'swyft' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'read_next_layout',
		'label'           => esc_html__( 'Layout', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => 'grid',
		'choices'         => array(
			'grid' => esc_html__( 'Grid', 'swyft' ),
			'list' => esc_html__( 'List', 'swyft' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'post_read_next_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => 'landscape',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'swyft' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'swyft' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'swyft' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'swyft' ),
			'landscape-21-9' => esc_html__( 'Landscape 21:9', 'swyft' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'swyft' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'swyft' ),
			'portrait-6-7'   => esc_html__( 'Portrait 6:7', 'swyft' ),
			'square'         => esc_html__( 'Square', 'swyft' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'post_read_next_image_size',
		'label'           => esc_html__( 'Image Size', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => 'csco-thumbnail',
		'choices'         => csco_get_list_available_image_sizes(),
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'read_next_excerpt',
		'label'           => esc_html__( 'Display excerpt', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'multicheck',
		'settings'        => 'post_read_next_meta',
		'label'           => esc_html__( 'Post Meta', 'swyft' ),
		'section'         => 'post_settings',
		'default'         => array( 'category', 'date', 'author' ),
		/**
		 * Post meta choices.
		 *
		 * @since 1.0.0
		 */
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category' => esc_html__( 'Category', 'swyft' ),
				'date'     => esc_html__( 'Date', 'swyft' ),
				'author'   => esc_html__( 'Author', 'swyft' ),
				'comments' => esc_html__( 'Comments', 'swyft' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_read_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
