<?php
/**
 * The template for displaying the hero 1 layout
 *
 * @package Swyft
 */

$args           = csco_get_hero_query_args();
$hero_post_meta = get_theme_mod( 'home_hero_meta', array( 'category', 'author', 'date' ) );

$parallax       = 'yes' === get_theme_mod( 'home_hero_slider_parallax', 'yes' ) ? true : false;
$autoplay       = 'yes' === get_theme_mod( 'home_hero_slider_autoplay', 'yes' ) ? true : false;
$autoplay_delay = 5000;

if ( $autoplay ) {
	$autoplay_delay = get_theme_mod( 'home_hero_slider_delay', 5000 );
}

$counter           = 0;
$hero_type         = get_theme_mod( 'home_hero_layout', 'hero-type-1' );
$image_size        = 'csco-large-uncropped';
$image_size_mobile = 'csco-thumbnail-uncropped';
$gap               = 32;

if ( 'hero-type-4' === $hero_type ) {
	$image_size        = 'csco-extra-large-uncropped';
	$image_size_mobile = 'csco-medium-uncropped';
	$gap               = 0;
}

?>

<section class="cs-home-hero cs-hero-type-1">
	<div
	class="cs-hero-type-1__slider"
	data-cs-autoplay="<?php echo esc_attr( $autoplay ); ?>"
	data-cs-autoplay-delay="<?php echo esc_attr( $autoplay_delay ); ?>"
	data-cs-parallax="<?php echo esc_attr( $parallax ); ?>"
	data-cs-gap="<?php echo esc_attr( $gap ); ?>"
	>
		<div class="cs-hero-type-1__wrapper" data-scheme="inverse">

			<?php
			$query = new \WP_Query( $args );

			if ( $query->have_posts() ) {
				while ( $query->have_posts() ) {
					$query->the_post();
					++$counter;
					?>

					<article class="cs-hero-type-1__item cs-entry">

						<div class="cs-entry__outer cs-entry__overlay cs-overlay-ratio cs-ratio-landscape-slider">
							<div class="cs-entry__inner cs-entry__thumbnail">
								<div class="cs-overlay-background">
									<?php the_post_thumbnail( $image_size_mobile ); ?>
									<?php the_post_thumbnail( $image_size ); ?>
								</div>
							</div>

							<div 
							class="cs-entry__inner cs-entry__content cs-overlay-content"
							data-swiper-parallax-x="-400"
							data-swiper-parallax-duration="800"
							>

								<?php csco_get_post_meta( array( 'author', 'date', 'comments' ), true, $hero_post_meta ); ?>

								<h2 class="cs-entry__title">
									<?php echo esc_attr( get_the_title() ); ?>
								</h2>

								<div class="cs-entry__subtitle">
									<?php echo esc_attr( get_the_excerpt() ); ?>
								</div>

								<?php csco_get_post_meta( array( 'category' ), true, $hero_post_meta ); ?>

							</div>

							<a class="cs-overlay-link" href="<?php the_permalink(); ?>" title="<?php echo esc_attr( get_the_title() ); ?>"></a>
						</div>

					</article>

					<?php
				}
				wp_reset_postdata();
			}
			?>
		</div>

		<?php if ( $counter > 1 ) { ?>
			<?php if ( $counter <= 5 ) { ?>
				<div class="cs-hero-type-1__pagination"></div>
			<?php } ?>
			<div class="cs-hero-type-1__button-prev"></div>
			<div class="cs-hero-type-1__button-next"></div>
		<?php } ?>
	</div>
</section>
